@@ -55,7 +55,9 @@ def map_json(mapping_config, json_data, strict=False):
                 list_result = []
                 list_json = walk_dict(json_data, key, strict)
                 if dict == type(list_json):
-                    list_result.append(list_json.get(config))
+                    data = list_json.get(config)
+                    if data:
+                        list_result.append()
                 else:
                     for lj in list_json:
                         if config in lj:
